@@ -8,7 +8,7 @@ use warnings;
 use Carp;
 use Storable ();
 
-our $VERSION = '0.004_02';
+our $VERSION = '0.005_01';
 
 use constant HASH_REF	=> ref {};
 
@@ -190,7 +190,8 @@ L<HTTP::Tiny|HTTP::Tiny> (the real one).
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Test-Pod-LinkCheck-Lite/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -198,7 +199,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2019-2020 by Thomas R. Wyant, III
+Copyright (C) 2019-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
